@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,7 +12,10 @@
 #include "articleviewerwebenginepage.h"
 #include "urlhandler/webengine/urlhandlerwebengine.h"
 #include "webengine/urlhandlerwebenginemanager.h"
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeech>
+#endif
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <WebEngineViewer/WebEngineManageScript>
@@ -27,6 +30,7 @@
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <MessageViewer/ViewerPluginToolManager>
 #include <QApplication>
 #include <QClipboard>
 #include <QFileDialog>
@@ -35,7 +39,6 @@
 #include <QPrinter>
 #include <QWebEngineProfile>
 #include <QWebEngineUrlRequestInterceptor>
-#include <viewerplugintoolmanager.h>
 
 #include <WebEngineViewer/BlockExternalResourcesUrlInterceptor>
 #include <WebEngineViewer/BlockTrackingUrlInterceptor>
@@ -120,9 +123,7 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     connect(phishingDatabase(), &WebEngineViewer::LocalDataBaseManager::checkUrlFinished, this, &ArticleViewerWebEngine::slotCheckedUrlFinished);
 }
 
-ArticleViewerWebEngine::~ArticleViewerWebEngine()
-{
-}
+ArticleViewerWebEngine::~ArticleViewerWebEngine() = default;
 
 void ArticleViewerWebEngine::execPrintPreviewPage(QPrinter *printer, int timeout)
 {
@@ -197,6 +198,9 @@ void ArticleViewerWebEngine::slotSaveLinkAs()
             job->addMetaData(QStringLiteral("MaxCacheSize"), QStringLiteral("0")); // Don't store in http cache.
             job->addMetaData(QStringLiteral("cache"), QStringLiteral("cache")); // Use entry from cache if available.
             KJobWidgets::setWindow(job, this);
+            if (Settings::self()->disableSaveAsNotification()) {
+                job->setFinishedNotificationHidden(true);
+            }
             job->uiDelegate()->setAutoErrorHandlingEnabled(true);
         }
     });
@@ -307,10 +311,12 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_unmute")));
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
         popup.addSeparator();
         popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
     }
+#endif
     popup.exec(mapToGlobal(result.pos()));
 }
 
@@ -530,7 +536,7 @@ QList<QAction *> ArticleViewerWebEngine::viewerPluginActionList(MessageViewer::V
     if (mViewerPluginToolManager) {
         return mViewerPluginToolManager->viewerPluginActionList(features);
     }
-    return QList<QAction *>();
+    return {};
 }
 
 void ArticleViewerWebEngine::slotActivatePlugin(MessageViewer::ViewerPluginInterface *interface)
