@@ -13,12 +13,12 @@
 #include "article.h"
 #include "articlejobs.h"
 #include "feedretriever.h"
-#include "feedstorage.h"
 #include "fetchqueue.h"
 #include "folder.h"
 #include "job/downloadfeediconjob.h"
 #include "notificationmanager.h"
-#include "storage.h"
+#include "storage/feedstorage.h"
+#include "storage/storage.h"
 #include "treenodevisitor.h"
 #include "types.h"
 #include "utils.h"
@@ -41,7 +41,8 @@
 using Syndication::ItemPtr;
 using namespace Akregator;
 
-template<typename Key, typename Value, template<typename, typename> class Container> QVector<Value> valuesToVector(const Container<Key, Value> &container)
+template<typename Key, typename Value, template<typename, typename> class Container>
+QVector<Value> valuesToVector(const Container<Key, Value> &container)
 {
     QVector<Value> values;
     values.reserve(container.size());
@@ -204,12 +205,12 @@ bool Akregator::Feed::accept(TreeNodeVisitor *visitor)
 
 QVector<const Akregator::Folder *> Akregator::Feed::folders() const
 {
-    return QVector<const Folder *>();
+    return {};
 }
 
 QVector<Folder *> Akregator::Feed::folders()
 {
-    return QVector<Folder *>();
+    return {};
 }
 
 QVector<const Akregator::Feed *> Akregator::Feed::feeds() const
@@ -710,8 +711,8 @@ bool Akregator::Feed::isExpired(const Article &a) const
         expiryAge = Settings::maxArticleAge() * 24 * 3600;
     } else // otherwise check if this feed has limitArticleAge set
         if (d->m_archiveMode == limitArticleAge) {
-        expiryAge = d->m_maxArticleAge * 24 * 3600;
-    }
+            expiryAge = d->m_maxArticleAge * 24 * 3600;
+        }
 
     return expiryAge != -1 && a.pubDate().secsTo(now) > expiryAge;
 }
