@@ -17,21 +17,19 @@
 
 #include <KLocalizedString>
 
-#include <KFormat>
+#include <KIO/Global>
 
 using namespace Syndication;
 using namespace Akregator;
 
-ArticleFormatter::ArticleFormatter()
-{
-}
+ArticleFormatter::ArticleFormatter() = default;
 
 ArticleFormatter::~ArticleFormatter() = default;
 
 QString ArticleFormatter::formatEnclosure(const Enclosure &enclosure)
 {
     if (enclosure.isNull()) {
-        return QString();
+        return {};
     }
 
     const QString title = !enclosure.title().isEmpty() ? enclosure.title() : enclosure.url();
@@ -39,11 +37,11 @@ QString ArticleFormatter::formatEnclosure(const Enclosure &enclosure)
     const QString type = enclosure.type();
     QString inf;
     if (!type.isEmpty() && length > 0) {
-        inf = i18n("(%1, %2)", type, KFormat().formatByteSize(length));
+        inf = i18n("(%1, %2)", type, KIO::convertSize(length));
     } else if (!type.isNull()) {
         inf = type;
     } else if (length > 0) {
-        inf = KFormat().formatByteSize(length);
+        inf = KIO::convertSize(length);
     }
     const QString str = QStringLiteral("<a href=\"%1\">%2</a> %3").arg(enclosure.url(), title, inf);
     return str;
