@@ -9,8 +9,8 @@
 #include "mainwindow.h"
 #include "akregator_part.h"
 #include "akregatorconfig.h"
-#include "kcoreaddons_version.h"
 #include "trayicon.h"
+#include <Libkdepim/ProgressManager>
 #include <Libkdepim/ProgressStatusBarWidget>
 #include <Libkdepim/StatusbarProgressWidget>
 #include <PimCommon/BroadcastStatus>
@@ -26,11 +26,15 @@
 #include <KShortcutsDialog>
 #include <KSqueezedTextLabel>
 #include <KStandardAction>
+#include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <KXMLGUIFactory>
 #include <QApplication>
+#include <QFontDatabase>
 #include <QMenuBar>
 #include <QStatusBar>
+#include <QTimer>
+#include <QToolButton>
 
 using namespace Akregator;
 
@@ -39,8 +43,9 @@ MainWindow::MainWindow(QWidget *parent)
     , m_part()
     , m_statusLabel(new KSqueezedTextLabel(this))
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setPluginLoadingMode(DoNotLoadPlugins);
-
+#endif
     // set the shell's ui resource file
     setXMLFile(QStringLiteral("akregator_shell.rc"));
 
@@ -75,6 +80,10 @@ MainWindow::MainWindow(QWidget *parent)
         });
     }
 
+    mShowFullScreenAction = KStandardAction::fullScreen(nullptr, nullptr, this, actionCollection());
+    actionCollection()->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
+    connect(mShowFullScreenAction, &QAction::toggled, this, &MainWindow::slotFullScreen);
+
     setStandardToolBarMenuEnabled(true);
     createStandardStatusBarAction();
 
@@ -83,6 +92,26 @@ MainWindow::MainWindow(QWidget *parent)
     connect(qApp, &QCoreApplication::aboutToQuit, this, &MainWindow::slotOnShutdown);
 }
 
+void MainWindow::slotFullScreen(bool t)
+{
+    KToggleFullScreenAction::setFullScreen(this, t);
+    QMenuBar *mb = menuBar();
+    if (t) {
+        auto b = new QToolButton(mb);
+        b->setDefaultAction(mShowFullScreenAction);
+        b->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Ignored));
+        b->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+        mb->setCornerWidget(b, Qt::TopRightCorner);
+        b->setVisible(true);
+        b->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    } else {
+        QWidget *w = mb->cornerWidget(Qt::TopRightCorner);
+        if (w) {
+            w->deleteLater();
+        }
+    }
+}
+
 void MainWindow::slotToggleMenubar(bool dontShowWarning)
 {
     if (menuBar()) {
@@ -106,7 +135,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
 
 void MainWindow::updateHamburgerMenu()
 {
-    QMenu *menu = new QMenu(this);
+    auto *menu = new QMenu(this);
     menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
     mHamburgerMenu->setMenu(menu);
 }
@@ -141,13 +170,35 @@ bool MainWindow::loadPart()
 void MainWindow::setupProgressWidgets()
 {
     auto progressStatusBarWidget = new KPIM::ProgressStatusBarWidget(statusBar(), this);
-    statusBar()->addPermanentWidget(progressStatusBarWidget->littleProgress(), 0);
+    m_statusbarProgress = progressStatusBarWidget->littleProgress();
+    statusBar()->addPermanentWidget(m_statusbarProgress, 0);
+
+    // The progress widget blocks a large part of the status bar, but is empty
+    // most of the time. Hide it when unused, allowing a longer status label.
+    m_hideProgressTimer = new QTimer(this);
+    m_hideProgressTimer->setSingleShot(true);
+    connect(m_hideProgressTimer, &QTimer::timeout,
+            m_statusbarProgress, &QWidget::hide);
+
+    connect(KPIM::ProgressManager::instance(), &KPIM::ProgressManager::progressItemAdded,
+            this, &MainWindow::updateStatusbarProgressVisibility);
+    connect(KPIM::ProgressManager::instance(), &KPIM::ProgressManager::progressItemCompleted,
+            this, &MainWindow::updateStatusbarProgressVisibility);
+    m_statusbarProgress->hide();
 }
 
-MainWindow::~MainWindow()
+void MainWindow::updateStatusbarProgressVisibility()
 {
+    if (KPIM::ProgressManager::instance()->isEmpty()) {
+        m_hideProgressTimer->start(5000);
+    } else {
+        m_hideProgressTimer->stop();
+        m_statusbarProgress->show();
+    }
 }
 
+MainWindow::~MainWindow() = default;
+
 void MainWindow::saveProperties(KConfigGroup &config)
 {
     if (!m_part) {
